@@ -404,7 +404,9 @@ void checkIndexSetForCodim ( const Grid &grid, const GridView &view,
   {
     typedef typename GridView :: template Codim< 0 > :: Iterator Iterator;
     // choose the right reference element 
+    #ifndef NDEBUG
     const Iterator refend = view.template end< 0 >();
+    #endif
     Iterator refit = view.template begin< 0 >();
     assert( refit != refend );
       
