@@ -186,7 +186,7 @@ insertBoundarySegment(const std::vector<unsigned int>& vertices)
 template <int dimworld>
 void Dune::GridFactory<Dune::UGGrid<dimworld> >::
 insertBoundarySegment(const std::vector<unsigned int>& vertices,
-                      const shared_ptr<BoundarySegment<dimworld> > boundarySegment)
+                      const shared_ptr<BoundarySegment<dimworld> > &boundarySegment)
 {
     array<int, dimworld*2-2> segmentVertices;
 
@@ -480,6 +480,12 @@ createGrid()
         // so we would be out of sync if we don't do this here...)
         if (CreateAlgebra(grid_->multigrid_) != UG_NS<dimworld>::GM_OK)
             DUNE_THROW(IOError, "Call of 'UG::D" << dimworld << "::CreateAlgebra' failed!");
+
+        // Create an empty levelIndexSet for level 0.
+        // Even though it's empty until the first load balancing
+        // it should still be there in case someone wants to access it.
+        grid_->levelIndexSets_.resize(1);
+        grid_->levelIndexSets_[0] = new UGGridLevelIndexSet<const UGGrid<dimworld> >();
         
         /* here all temp memory since CreateMultiGrid is released */
         Release(grid_->multigrid_->theHeap, UG::FROM_TOP, grid_->multigrid_->MarkKey);
